from matplotlib import pyplot as plt
import pandas as pd
import numpy as np

# ucitavamo podatke iz fajla
data = pd.read_csv("income_survey.csv")
# izdvajamo obelezene grupe podataka
age = data["Age"]
all_devs = data["All_Devs"]
py_devs = data["Python"]
js_devs = data["JavaScript"]

# ukupna medijana svih zarada
overall_median = 57826

# definisemo prvi grafik
# figure je kontejner koji sadrzi nas grafik
# posmatrajte ga kao prozor

plt.figure(1)
# crtamo grafik medijalnih zarada po godinama
plt.plot(age, all_devs, label="All devs")
# plt.plot(age, py_devs, label="Python")
#plt.plot(age, js_devs, label="JavaScript")

# i farbamo prostor izmedju ukupne medijane i medijane po godinama
# moramo da farbamo iz dva dela
# prvo zarade iznad medijalne
# pa onda zarade ispod medijalne
# kriterijum koji koristirmo se navodi 
# u okviru parametra where
# parametar y2 definise granicnu vrednost na y osi na grafiku
# parametar interpolate omogucava da 
plt.fill_between(age, all_devs, alpha=0.25, y2=overall_median,
         where=(all_devs > overall_median), interpolate=True)
plt.fill_between(age, all_devs, alpha=0.25, y2=overall_median,
         where=(all_devs <= overall_median), interpolate=True)

# podesavamo uobicajene parametre grafika
# bitno: za svaku figuru moraju da se navedu odvojena podesavanja
plt.legend()
plt.title("Median Income (USD) Survey")
plt.xlabel("Age")
plt.ylabel("Median Income (USD)")
plt.grid()
plt.tight_layout()
plt.savefig("income_vs_median.png")

# na drugom prozoru crtamo razlike izmedju medijalnih zarada
# i medijalnih zarada pajton programera
plt.figure(2)
# prvo crtamo obe krive
plt.plot(age, all_devs, label="All Devs", linestyle="--")
plt.plot(age, py_devs, linestyle="solid", label="Python")

# zatim farbamo prostor izmedju
plt.fill_between(age, py_devs, alpha=0.25, y2=all_devs,
         where=(py_devs > all_devs), interpolate=True)
plt.fill_between(age, py_devs, alpha=0.25, y2=all_devs,
         where=(py_devs <= all_devs), interpolate=True)

# uobicajena podesavanja
plt.legend()
plt.title("Median Income (USD) Survey")
plt.xlabel("Age")
plt.ylabel("Median Income (USD)")
plt.grid()
plt.tight_layout()
# cuvamo sliku grafika
plt.savefig("all_vs_python.png")
# prikazujemo grafik
plt.show()