from matplotlib import pyplot as plt
import pandas as pd
import numpy as np
from collections import Counter

# program kreira sortirani prikaz popularnosti
# programskih jezika pomocu horizontalnih stubica

# definisemo stil koji koristimo
plt.style.use("ggplot")

# ucitavamo podatke iz csv datoteke
data = pd.read_csv("popularity.csv")
# izdvajamo obelezene grupe podataka
ids = data["Responder_id"]
lang_responses = data["LanguagesWorkedWith"]

# koristimo klasu Counter() da bismo prebrojali frekvencije
# pojavljivanja svakog jezika
lcounter = Counter()
for response in lang_responses:
    lcounter.update(response.split(";"))

# u petlji, peske izdvajamo 15 najpopularijih jezima
languages = []
popularity = []
for item in lcounter.most_common(15):
    languages.append(item[0])
    popularity.append(item[1])

# sortiramo ih opadajuce po popularnosti
languages.reverse()
popularity.reverse()

# crtamo horizontalni bar chart
plt.barh(languages, popularity)

# uobicajeno formatiranje prikaza
plt.title("Language popularity")
# bitno: kod horizontalnih stubica moramo da obrnemo
#        opise osa
plt.ylabel("Language")
plt.xlabel("Popularity")

plt.tight_layout()
# cuvamo grafik kao sliku
plt.savefig("lang_popularity_barh.png")
# prikazujemo grafik
plt.show()


